@@ -37,15 +37,18 @@ def hic2matrix(path,res,chr,gt):
         print("Please check your genome_table file. Is it tab separated ?")
         exit(1)
 
+    print("Start dump matrix from hic file")
     codepath = os.path.dirname(os.path.realpath(__file__))
     makeIntra = codepath+"/extract/makeMatrixIntra.sh"
     juicer = codepath+"/jc/jctool_1.11.04.jar"
     foldername = "./MatrixTemp"+str(random.random())
     os.system("bash "+makeIntra+" "+"KR"+" "+"."+" "+path+" "+str(res)+" "+gt+" "+juicer+" "+chr+" "+foldername + "> info.txt")
     matrixpath = foldername+"/"+str(res)+"/observed.KR."+chr+".matrix.gz"
+    print("Finish dump")
     return(matrixpath)
 
 def cool2matrix(path,res,chr,gt):
+    print("Start dump matrix from cool file")
     if not gt:
         print("cool require genome_table file");exit(1)
     codepath = os.path.dirname(os.path.realpath(__file__))
@@ -53,4 +56,5 @@ def cool2matrix(path,res,chr,gt):
     foldername = "./MatrixTemp"+str(random.random())
     os.system("bash "+makeIntra+" "+path+" "+str(res)+" "+chr+" "+gt+" "+foldername + "> info.txt")
     matrixpath = foldername+"/"+str(res)+"/"+chr+".matrix.gz"
+    print("Finish dump")
     return(matrixpath)
